@@ -16,4 +16,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .modeling_bert import PipelinedBertForPreTraining, PipelinedBertForQuestionAnswering
+from .modeling_bert import (
+    PipelinedBertForMultipleChoice,
+    PipelinedBertForPreTraining,
+    PipelinedBertForQuestionAnswering,
+    PipelinedBertForSequenceClassification,
+    PipelinedBertForTokenClassification,
+)
