@@ -16,4 +16,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .modeling_roberta import PipelinedRobertaForQuestionAnswering
+from .modeling_roberta import (
+    PipelinedRobertaForMultipleChoice,
+    PipelinedRobertaForQuestionAnswering,
+    PipelinedRobertaForSequenceClassification,
+    PipelinedRobertaForTokenClassification,
+)
